@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of mediastreamer2 
+ * This file is part of mediastreamer2
  * (see https://gitlab.linphone.org/BC/public/mediastreamer2).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -32,8 +32,8 @@ extern "C" {
  * Prequisite: the user code must not destroy every MSTask it holds before the MSWorkerThread is destroyed,
  * otherwise a crash will occur.
  */
-	
-struct _MSWorkerThread{
+
+struct _MSWorkerThread {
 	ms_thread_t thread;
 	ms_cond_t cond;
 	ms_mutex_t mutex;
@@ -49,15 +49,15 @@ typedef struct _MSWorkerThread MSWorkerThread;
 
 typedef void (*MSTaskFunc)(void *);
 
-typedef enum _MSTaskState{
+typedef enum _MSTaskState {
 	MSTaskInit,
 	MSTaskQueued,
 	MSTaskCancelled,
 	MSTaskRunning,
 	MSTaskDone /**< the task was completed. This is the final state even for cancelled tasks.*/
-}MSTaskState;
+} MSTaskState;
 
-struct _MSTask{
+struct _MSTask {
 	MSWorkerThread *worker;
 	MSTaskFunc func;
 	void *data;
@@ -78,7 +78,7 @@ MS2_PUBLIC void ms_task_cancel(MSTask *task);
 /*
  * Cancel a task and schedule it for destruction.
  * If the task is already completed, it is destroyed synchronously.
- * Unlike ms_task_destroy(), ms_task_cancel_and_destroy() does not wait 
+ * Unlike ms_task_destroy(), ms_task_cancel_and_destroy() does not wait
  * the task to be processed by the worker thread, but returns immediately.
  */
 MS2_PUBLIC void ms_task_cancel_and_destroy(MSTask *task);
@@ -87,30 +87,29 @@ MS2_PUBLIC void ms_task_cancel_and_destroy(MSTask *task);
  */
 MS2_PUBLIC void ms_task_wait_completion(MSTask *task);
 
-/* 
+/*
  * Automatically cancels if necessary, and waits for completion before destroying the task.
  */
-MS2_PUBLIC void ms_task_destroy(MSTask *task); 
+MS2_PUBLIC void ms_task_destroy(MSTask *task);
 
 /* Create a worker thread. Name is mandatory to ease debugging. */
-MS2_PUBLIC MSWorkerThread * ms_worker_thread_new(const char *name);
+MS2_PUBLIC MSWorkerThread *ms_worker_thread_new(const char *name);
 /* Add a task to execute. The task object is internal, not returned. For simple usages. */
 MS2_PUBLIC void ms_worker_thread_add_task(MSWorkerThread *obj, MSTaskFunc fn, void *data);
 /* Add a task to execute. A MSTask object is returned to the caller, that can be wait upon. It must be destroyed. */
-MS2_PUBLIC MSTask * ms_worker_thread_add_waitable_task(MSWorkerThread *obj, MSTaskFunc fn, void *data);
+MS2_PUBLIC MSTask *ms_worker_thread_add_waitable_task(MSWorkerThread *obj, MSTaskFunc fn, void *data);
 
 /* Add a task that must be repeated at regular interval.
- * Note that with the current implementation, the scheduling is not accurate: granularity is 10 ms, and there is no catchup.
+ * Note that with the current implementation, the scheduling is not accurate: granularity is 10 ms, and there is no
+ * catchup.
  */
-MS2_PUBLIC MSTask * ms_worker_thread_add_repeated_task(MSWorkerThread *obj, MSTaskFunc func, void *data, int repeat_interval);
+MS2_PUBLIC MSTask *
+ms_worker_thread_add_repeated_task(MSWorkerThread *obj, MSTaskFunc func, void *data, int repeat_interval);
 
 MS2_PUBLIC void ms_worker_thread_destroy(MSWorkerThread *obj, bool_t finish_tasks);
 
-
 #ifdef __cplusplus
 }
 #endif
 
 #endif
-
-
